//
//
// Pov-file for the POVRAY ray-tracing program 
// ===========================================
//
// Made when: March 17 2012, updated June 24 2012.
//
// By Stefan Spaennare, Lund, Sweden
//
// E-mail: stefan@spaennare.se
//
// Home page of the author: 
// http://www.spaennare.se/index.html
//
// The image and this pov-file are available on the web-page:
// http://www.spaennare.se/povray.html
//
// This pov-file is free to copy or change if this header appears
// in all copies.
//
// References:
//
// The POVRAY ray-tracing program can be downloaded for free from:
// http://www.povray.org
//
//    


#version 3.6

#include "colors.inc"                 
#include "shapes.inc"
#include "woods.inc"


camera {
   location <0.0,  1.5,  -2.0>
   direction <0.0, 0.0,  1.0>
   up  <0.0,  1.0,  0.0>
   right <4/3, 0.0, 0.0>
   look_at <0, 0 ,0>
}


light_source { <28.0, 120.0, -80.0> 
         color red 0.5 green 0.5 blue 0.5  
         spotlight
         point_at <0.0, 0.25, 0.25>
         tightness 800.0
         radius 30.0
         falloff 45.0        
         
}        



light_source {
    <0.0,80.0,-40>, rgb <0.7,0.7,0.7> shadowless
}



sky_sphere { pigment {rgb <0.0,0.0,0.0>} }


#declare F_Glass3 =
finish  {
    ambient 0.1
    diffuse 0.1
    reflection 0.1
    refraction 1.0
    ior 1.45
    specular 0.8
    roughness 0.003
    phong 1.0
    phong_size 400.0
}       

#declare texture1 = texture {     
      pigment {
         checker color rgb <0.4, 0.4, 0.6> color rgb 0.8 
         scale 4.0
      }
      finish {
         phong 0.2
	 phong_size 1.0
         ambient 0.8
         diffuse 0.2
      }      
}


# declare glasstexture = texture {
    pigment { color rgbf <0.98, 0.98, 0.98, 0.90> }
    finish { F_Glass3
         reflection 0.07
    }
}    


#declare steeltexture = texture {
   pigment { color red 0.5 green 0.45 blue 0.35 }
   finish {
      ambient 0.035
      reflection 0.4
      diffuse 1.0
      phong 1.0
      phong_size 3.0
   }
}    

#declare tabletexture = texture {
   pigment { color red 0.7 green 0.7 blue 0.7 }
   finish {
      ambient 0.030
      reflection 0.09
      diffuse 1.0
      phong 1.0
      phong_size 3.0
   }
}   


#declare table2 = union {
    box { <-5.0, -0.07, -2.2> <5.0, 0.07, 2.2> } 
      texture { texture1 
      scale 0.02
    }    
}               
      
      
#declare table1 = union {
    box { <-5.0, -0.07, -2.2> <5.0, 0.07, 2.2> } 
      texture { tabletexture 
    }    
}  
     

#declare c1 = cylinder {
   -50.5*x, 50.5*x, 2.125 
} 
     

#declare c2 = cylinder {
   -63.75*y, 63.75*y, 2.125 
} 
  

#declare c3 = cylinder {
   -49.3*z, 49.3*z, 2.125 
}  
 

#declare c4 = cylinder {
   -114*y 0*y 0.15
}   
                

#declare w1a = union {  

    object { c4    
       rotate -26*x
       translate -53.675*z 
               
    }  
       
    texture { glasstexture }    
} 
   

#declare w1b = union {  

    object { c4  
       rotate 26*x    
       translate 54.0*z       
    }                   
    
    texture { glasstexture }    
}
             

#declare b1 = union {

   sphere { -114*y, 8.75
   }  
   
   object { 
      intersection {
         cylinder { -2.8*z 2.8*z 1.15 }
         cylinder { -2.8*z 2.8*z 0.55 open inverse}
      }     
      translate -104.5*y
   }        
   
   texture { steeltexture }
}    


#declare ball1 = union {
    object { b1  
    }
    
    object { w1a
    } 
    
    object { w1b        
    }     
}


#declare t1 = intersection {
   torus { 4.0, 2.125 }
   plane { 1.0*z, 0.0 inverse }    
   plane { 1.0*x, 0.0 inverse }
} 


#declare cr1 = union {  

   object { t1 
      rotate 90*x  
      rotate 90*z 
      translate 63.75*y
      translate 50.5*x
   } 
         
   object { t1 
      rotate 90*x  
      rotate 90*z  
      rotate 180*y
      translate 63.75*y
      translate -50.5*x
   }  
   
                          
   object {c1   
      translate 67.75*y
   }  
   
   
   object {c2   
      translate 54.5*x
   } 
   
    object {c2   
      translate -54.5*x
   }
   
   texture { steeltexture }
}   

 
#declare cr2 = union {  

   object { t1       
      rotate 90*z   
      rotate 180*x
      translate -63.75*y
      translate 54.5*x  
      translate -49.3*z
   } 
         
   object { t1   
      rotate 90*z
      rotate 180*x
      translate -63.75*y
      translate -54.5*x 
      translate -49.3*z
   }   
   
   
    object { t1       
      rotate 90*z   
      rotate 90*x
      translate -63.75*y
      translate 54.5*x  
      translate 49.3*z
   } 
         
   object { t1   
      rotate 90*z
      rotate 90*x
      translate -63.75*y
      translate -54.5*x 
      translate 49.3*z
   }
   
                          
   object {c3   
      translate 54.5*x
      translate -67.75*y
   }  
          
          
   object {c3   
      translate -54.5*x 
      translate -67.75*y
   }        
   
   texture { steeltexture }
} 


#declare craddle = union {
   object { cr1  
      translate -53.3*z
   }   
   object { cr1
      translate 53.3*z
   }  
   object { cr2
   }   
}  


union {

    object { table1 }   
    
    translate -1.1*y
    translate 1.0*z
    rotate 15*x
    
}  


union {  

   object { craddle }   
   
// Set the z-angle for each ball. For example -45 degrees.
   
   object { ball1  
      rotate -0*z    
      translate 35.0*x
      translate 65.625*y       
   }   
   
   object { ball1 
      rotate -0*z
      translate 17.5*x 
      translate 65.625*y     
   } 
       
   object { ball1 
      rotate -0*z 
      translate 0.0*x 
      translate 65.625*y     
   } 
    
   
   object { ball1  
      rotate -0*z
      translate -17.5*x
      translate 65.625*y       
   }
   
    object { ball1   
      rotate -45*z   
      translate -35.0*x  
      translate 65.625*y
                  
   }   
   
   
// The whole Newtons Cradle can be rotated by
// changing the y-angle. For example -85 degrees.
   
   rotate -5*y   
   scale 0.013  
   translate -0.1*y 
   translate 0.7*z
   rotate 15*x
   
}  
 

// End of pov file.


